Package: pathview
Type: Package
Title: a tool set for pathway based data integration and visualization
Version: 1.52.0
Date: 2025-03-28
Author: Weijun Luo
Maintainer: Weijun Luo <luo_weijun@yahoo.com>
Description: Pathview is a tool set for pathway based data integration
        and visualization. It maps and renders a wide variety of
        biological data on relevant pathway graphs. All users need is
        to supply their data and specify the target pathway. Pathview
        automatically downloads the pathway graph data, parses the data
        file, maps user data to the pathway, and render pathway graph
        with the mapped data. In addition, Pathview also seamlessly
        integrates with pathway and gene set (enrichment) analysis
        tools for large-scale and fully automated analysis.
biocViews: Pathways, GraphAndNetwork, Visualization, GeneSetEnrichment,
        DifferentialExpression, GeneExpression, Microarray, RNASeq,
        Genetics, Metabolomics, Proteomics, SystemsBiology, Sequencing
Depends: R (>= 3.5.0)
Imports: KEGGgraph, XML, Rgraphviz, graph, png, AnnotationDbi,
        org.Hs.eg.db, KEGGREST, methods, utils
Suggests: gage, org.Mm.eg.db, RUnit, BiocGenerics
License: GPL (>=3.0)
URL: https://github.com/datapplab/pathview, https://pathview.uncc.edu/
LazyLoad: yes
LazyData: yes
Config/pak/sysreqs: make libpng-dev libxml2-dev libssl-dev zlib1g-dev
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 12:37:26 UTC
RemoteUrl: https://github.com/bioc/pathview
RemoteRef: RELEASE_3_23
RemoteSha: 18f70b18cbfe57bec7ef629d6e21f63f155db044
NeedsCompilation: no
Packaged: 2026-04-29 13:51:38 UTC; root
Built: R 4.6.0; ; 2026-04-29 14:00:15 UTC; unix
